==> com.liferay.commerce.api-1.1.0-sources.jar: com/liferay/commerce/constants/CommerceActionKeys.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.commerce.constants;

/**
 * @author Andrea Di Giorgi
 */
public class CommerceActionKeys {

	public static final String MANAGE_COMMERCE_ADDRESSES =
		"MANAGE_COMMERCE_ADDRESSES";

	public static final String MANAGE_COMMERCE_AVAILABILITY_ESTIMATES =
		"MANAGE_COMMERCE_AVAILABILITY_ESTIMATES";

	public static final String MANAGE_COMMERCE_COUNTRIES =
		"MANAGE_COMMERCE_COUNTRIES";

	public static final String MANAGE_COMMERCE_PAYMENT_METHODS =
		"MANAGE_COMMERCE_PAYMENT_METHODS";

	public static final String MANAGE_COMMERCE_PRODUCT_DEFINITION_INVENTORY =
		"MANAGE_COMMERCE_PRODUCT_DEFINITION_INVENTORY";

	public static final String MANAGE_COMMERCE_SHIPMENTS =
		"MANAGE_COMMERCE_SHIPMENTS";

	public static final String MANAGE_COMMERCE_SHIPPING_METHODS =
		"MANAGE_COMMERCE_SHIPPING_METHODS";

	public static final String MANAGE_COMMERCE_TAX_METHODS =
		"MANAGE_COMMERCE_TAX_METHODS";

	public static final String MANAGE_COMMERCE_WAREHOUSES =
		"MANAGE_COMMERCE_WAREHOUSES";

}

==> com.liferay.commerce.api-3.0.0-sources.jar: com/liferay/commerce/constants/CommerceActionKeys.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.commerce.constants;

/**
 * @author Andrea Di Giorgi
 */
public class CommerceActionKeys {

	public static final String MANAGE_COMMERCE_ADDRESSES =
		"MANAGE_COMMERCE_ADDRESSES";

	public static final String MANAGE_COMMERCE_AVAILABILITY_ESTIMATES =
		"MANAGE_COMMERCE_AVAILABILITY_ESTIMATES";

	public static final String MANAGE_COMMERCE_COUNTRIES =
		"MANAGE_COMMERCE_COUNTRIES";

	public static final String MANAGE_COMMERCE_HEALTH_STATUS =
		"MANAGE_COMMERCE_HEALTH_STATUS";

	public static final String MANAGE_COMMERCE_ORDER_WORKFLOWS =
		"MANAGE_COMMERCE_ORDER_WORKFLOWS";

	public static final String MANAGE_COMMERCE_PAYMENT_METHODS =
		"MANAGE_COMMERCE_PAYMENT_METHODS";

	public static final String MANAGE_COMMERCE_PRODUCT_DEFINITION_INVENTORY =
		"MANAGE_COMMERCE_PRODUCT_DEFINITION_INVENTORY";

	public static final String MANAGE_COMMERCE_SHIPMENTS =
		"MANAGE_COMMERCE_SHIPMENTS";

	public static final String MANAGE_COMMERCE_SHIPPING_METHODS =
		"MANAGE_COMMERCE_SHIPPING_METHODS";

	public static final String MANAGE_COMMERCE_TAX_METHODS =
		"MANAGE_COMMERCE_TAX_METHODS";

	public static final String MANAGE_COMMERCE_WAREHOUSES =
		"MANAGE_COMMERCE_WAREHOUSES";

}
